@@ -24,6 +24,45 @@ UserMetadataKey = constr(regex=r"^\w+$")
 UserMetadataValue = Union[StrictBool, StrictInt, StrictFloat, StrictStr]
 
 
+class TimeSeriesMapping(Model):
+    """Attributes to identify a specific time series
+
+    Leaving the the dispatch_info or ensemble_member properties unset means
+    that the model adapter provides the missing information. Model Adapters may
+    also ignore properties if they are irrelevant. For example, a model task
+    may define a dispatch_info which would take precedence over the
+    dispatch_info defined here when writing output.
+    """
+
+    store_id: Optional[str] = None
+    path: str = Field(..., description="Path identifying the time series")
+    t0: Optional[datetime] = None
+    dispatch_info: Optional[str] = None
+    ensemble_member: Optional[str] = None
+
+
+class ElementMapping(Model):
+    """Element attribute
+
+    Very similar to the concept in the config store, but the UID is already defined"""
+
+    attribute: str = Field(..., description="Attribute of an element in the adapter")
+    attribute_index: Optional[int] = Field(
+        None,
+        description="Specific index of an attribute in the adapter, if it is an array",
+    )
+
+
+class DataMapping(Model):
+    """Associate an element mapping with a time series mapping"""
+
+    time_series: TimeSeriesMapping
+    element: ElementMapping
+    type: Optional[StrictStr] = Field(
+        None, description="Arbitrary string field to identify the mapping"
+    )
+
+
 class BaseElement(Model):
     domain: Optional[str] = None
     element_class: Optional[str] = None
@@ -43,6 +82,9 @@ class BaseElement(Model):
     user_metadata: Optional[Dict[UserMetadataKey, UserMetadataValue]] = Field(
         None, description="Optional dictionary of user-provided key-value pairs"
     )
+    time_series_mappings: Optional[List[DataMapping]] = Field(
+        None, description="List of timeseries mappings"
+    )
 
     @validator("display_name", always=True)
     def default_display_name(cls, v: Any, values: Dict[str, Any]) -> Any:
